@@ -10,8 +10,6 @@ int main(int argc, char** argv)
 	QApplication app(argc, argv);
 	QCoreApplication::setOrganizationName("KatanaSoft");
 	QCoreApplication::setApplicationName("Katana");
-	if (!installTranslationIfNecessary())
-		return 1;
 	MainWindow window;
 	window.show();
 	return app.exec();
