@@ -3,6 +3,7 @@
 #include "bible_text_source.h"
 #include "infinite_scroll.h"
 #include "install_dialog.h"
+#include "pdb_text_source.h"
 #include "search_dialog.h"
 #include "search_results.h"
 #include "select_dialog.h"
@@ -34,11 +35,10 @@ MainWindow::MainWindow() : QMainWindow(NULL)
 	QString book = settings.value("initial/book", "Genesis").toString();
 	int chapter = settings.value("initial/chapter", 0).toInt();
 	int verse = settings.value("initial/verse", 0).toInt();
-	mBible = getBibleInfo(translation);
+    mpViewer = createViewer(translation, book, chapter, verse);
 
 	QFrame* frame = new QFrame;
 	mLayout = new QHBoxLayout;
-    mpViewer = createViewer(book, chapter, verse);
 	mLayout->addWidget(mpViewer);
 	mSearchResults = new SearchResultsFrame();
 	mLayout->addWidget(mSearchResults);
@@ -78,8 +78,8 @@ MainWindow::~MainWindow()
 void MainWindow::closeEvent(QCloseEvent* event)
 {
 	QSettings settings;
-	settings.setValue("initial/translation", mBible->getBibleName());
-	settings.setValue("initial/book", mpViewer->getSourceName());
+	settings.setValue("initial/translation", mTextSource->getSourceName());
+	settings.setValue("initial/book", mTextSource->getSuperSectionName());
 	settings.setValue("initial/chapter", mpViewer->getCurrentSection());
 	settings.setValue("initial/verse", mpViewer->getCurrentParagraph());
 	settings.sync();
@@ -88,8 +88,9 @@ void MainWindow::closeEvent(QCloseEvent* event)
 
 void MainWindow::createMenu()
 {
-	menuBar()->addAction("Go to Chapter", this, SLOT(onSelectVerse()));
-	menuBar()->addAction("Select Translation", this, SLOT(selectTranslation()));
+	menuBar()->addAction("Go to Passage", this, SLOT(onSelectVerse()));
+	menuBar()->addAction("Select Translation", this,
+						SLOT(selectTranslation()));
 	menuBar()->addAction("Search", this, SLOT(onSearch()));
 	menuBar()->addAction("Settings", this, SLOT(onSettings()));
 }
@@ -160,7 +161,7 @@ void MainWindow::onSelectVerse()
 void MainWindow::selectVerse(QString startingFilter)
 {
 	SelectResult result;
-	if (::selectVerse(this, mBible, startingFilter, result))
+	if (::selectVerse(this, mTextSource, startingFilter, result))
 	{
 		switch (result.getType())
 		{
@@ -171,9 +172,12 @@ void MainWindow::selectVerse(QString startingFilter)
 			startSearch(result.search_GetText());
 			break;
 		case SelectResult::Type_SelectedVerse:
-			replaceViewer(createViewer(result.verse_GetBook(),
-									result.verse_GetChapter(), 0));
-			mSearchResults->hideResults();
+			{
+				QString translation = mTextSource->getSourceName();
+				mSearchResults->hideResults();
+				replaceViewer(createViewer(translation, result.verse_GetBook(),
+										result.verse_GetChapter(), 0));
+			}
 			break;
 		}
 	}
@@ -185,7 +189,7 @@ void MainWindow::search(QString text, QString scope)
 	progress.setWindowTitle("Searching...");
 	mCurrentSearchText = text;
 	QList<Key> results;
-	if (mBible->search(text, scope, &progress, results))
+	if (mTextSource->search(text, scope, &progress, results))
 		mSearchResults->handleResults(results);
 }
 
@@ -196,14 +200,22 @@ void MainWindow::startSearch(QString text)
 		search(dlg.getSearchText(), dlg.getSearchScope());
 }
 
-InfiniteScrollViewer* MainWindow::createViewer(QString book, int chapter,
+InfiniteScrollViewer* MainWindow::createViewer(QString translation,
+											QString book, int chapter,
 											int verse)
 {
-	TextSource* bibleSource = getBibleTextSource(mBible, book);
+	TextSource* newSource = NULL;
+	if (isPDBTranslation(translation))
+		newSource = getPDBTextSource(translation, book);
+	else
+		newSource = getBibleTextSource(translation, book);
+	if (newSource)
+		mTextSource = newSource;
+
 	QString highlight;
 	if (mSearchResults && mSearchResults->isShowingResults())
 		highlight = mCurrentSearchText;
-	return new InfiniteScrollViewer(this, bibleSource,
+	return new InfiniteScrollViewer(this, mTextSource,
 									shouldUseNewLineForVerses(),
 									getTextFontSize(),
 									chapter, verse,
@@ -215,14 +227,12 @@ void MainWindow::selectTranslation()
 	QString translation;
 	if (::selectTranslation(this, translation))
 	{
-		QString bookName = mpViewer->getSourceName();
+		QString bookName = mTextSource->getSuperSectionName();
 		int chapter = mpViewer->getCurrentSection();
 		int verse = mpViewer->getCurrentParagraph();
 
-		delete mBible;
-		mBible = getBibleInfo(translation);
-		replaceViewer(createViewer(bookName, chapter, verse));
 		mSearchResults->hideResults();
+		replaceViewer(createViewer(translation, bookName, chapter, verse));
 	}
 }
 
@@ -240,27 +250,27 @@ void MainWindow::onSettings()
 	{
 		QString newTranslation;
 		if (!dlg.getNewTranslation(newTranslation))
-			newTranslation = mBible->getBibleName();
+			newTranslation = mTextSource->getSourceName();
 
 		QString bookName = mpViewer->getSourceName();
 		int chapter = mpViewer->getCurrentSection();
 		int verse = mpViewer->getCurrentParagraph();
 
+		mSearchResults->hideResults();
 		// We deliberately reload the bible info here, because the translation
 		// might have been deleted out from under us, in which case
 		// getBibleInfo will simply return the last available Bible.
-		delete mBible;
-		mBible = getBibleInfo(newTranslation);
-		replaceViewer(createViewer(bookName, chapter, verse));
-		mSearchResults->hideResults();
+		replaceViewer(createViewer(newTranslation, bookName, chapter, verse));
 	}
 }
 
 void MainWindow::goToVerse(QString verse)
 {
-	Key key = mBible->getKeyForString(verse);
+	Key key = Key::fromString(verse);
 
-	replaceViewer(createViewer(key.mBook, key.mChapter, key.mVerse));
+	QString translation = mTextSource->getSourceName();
+	replaceViewer(createViewer(translation, key.mBook,
+							key.mChapter, key.mVerse));
 }
 void MainWindow::orientationChanged(const QString& newOrientation)
 {
